/*
 Copyright 2009 Virginia Polytechnic Institute and State University  

 Licensed under the Apache License, Version 2.0 (the "License"); 
 you may not use this file except in compliance with the License. 
 You may obtain a copy of the License at 
 
 http://www.apache.org/licenses/LICENSE-2.0 

 Unless required by applicable law or agreed to in writing, software 
 distributed under the License is distributed on an "AS IS" BASIS, 
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 See the License for the specific language governing permissions and 
 limitations under the License. 
*/

/*! CROSS Cognitive Radio API
 *
 * This header exports all public functions that comprise the CROSS function
 * library.  These are the functions that are used by the host application to
 * control the CROSS radio.  
 *
 * PUT MORE STUFF HERE
 */

#ifndef LIBCROSS_H
#define LIBCROSS_H

#include <stdint.h>
#include <string>

#include "components.h"
#include "containers.h"


/*! \brief Tell the system where the Shell component is located. 
 *
 * Sets the location of the shell component that the client code will be
 * communicating with. Note that this can be a local or remote destination.
 */

void SetCrossShellLocation(std::string hostname, std::string port);

Parameter* GetOptimalParameters(Observable *radioObservables, uint32_t numObservables, Parameter *currentParameters, uint32_t numCurrentParameters, Utility *radioUtilities, uint32_t numUtilities);

bool UpdateParameterPerformance(Parameter *p, uint32_t numParameters, Observable *o, uint32_t numObservables, Utility *u, uint32_t numUtilities);

uint32_t GetNum(std::string);

#endif
